==> pointpos_api-0.0.1.tar.gz: docs/UnitApi.md <==
# swagger.api.UnitApi

## Load the API package
```dart
import 'package:swagger/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createUnit**](UnitApi.md#createUnit) | **POST** /unit | Create Unit
[**deleteUnitByID**](UnitApi.md#deleteUnitByID) | **DELETE** /unit/{id} | Delete Unit By ID
[**findUnit**](UnitApi.md#findUnit) | **GET** /unit | Get Unit List
[**getUnitByID**](UnitApi.md#getUnitByID) | **GET** /unit/{id} | Get Unit By ID
[**updateUnitByID**](UnitApi.md#updateUnitByID) | **PUT** /unit/{id} | Update Unit By ID


# **createUnit**
> Unit createUnit(authorization, xAPIKey, body)

Create Unit

Create Unit

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new Unit(); // Unit | 

try { 
    var result = api_instance.createUnit(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling UnitApi->createUnit: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**Unit**](Unit.md)|  | 

### Return type

[**Unit**](Unit.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteUnitByID**
> deleteUnitByID(authorization, xAPIKey, id)

Delete Unit By ID

Delete Unit By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 

try { 
    api_instance.deleteUnitByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling UnitApi->deleteUnitByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findUnit**
> List<Unit> findUnit(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Unit List

Get Unit  List

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findUnit(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling UnitApi->findUnit: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<Unit>**](Unit.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getUnitByID**
> Unit getUnitByID(authorization, xAPIKey, id)

Get Unit By ID

Get Unit By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 

try { 
    var result = api_instance.getUnitByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling UnitApi->getUnitByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 

### Return type

[**Unit**](Unit.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateUnitByID**
> Unit updateUnitByID(authorization, xAPIKey, id, body)

Update Unit By ID

Update [object Object] By ID

### Example 
```dart
import 'package:swagger/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 
var body = new Unit(); // Unit | 

try { 
    var result = api_instance.updateUnitByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling UnitApi->updateUnitByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 
 **body** | [**Unit**](Unit.md)|  | 

### Return type

[**Unit**](Unit.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

==> pointpos_api-0.0.2.tar.gz: docs/UnitApi.md <==
# swagger.api.UnitApi

## Load the API package
```dart
import 'package:pointpos_api/api.dart';
```

All URIs are relative to *https://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createUnit**](UnitApi.md#createUnit) | **POST** /unit | Create Unit
[**deleteUnitByID**](UnitApi.md#deleteUnitByID) | **DELETE** /unit/{id} | Delete Unit By ID
[**findUnit**](UnitApi.md#findUnit) | **GET** /unit | Get Unit List
[**getUnitByID**](UnitApi.md#getUnitByID) | **GET** /unit/{id} | Get Unit By ID
[**updateUnitByID**](UnitApi.md#updateUnitByID) | **PUT** /unit/{id} | Update Unit By ID


# **createUnit**
> Unit createUnit(authorization, xAPIKey, body)

Create Unit

Create Unit

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var body = new Unit(); // Unit | 

try { 
    var result = api_instance.createUnit(authorization, xAPIKey, body);
    print(result);
} catch (e) {
    print("Exception when calling UnitApi->createUnit: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **body** | [**Unit**](Unit.md)|  | 

### Return type

[**Unit**](Unit.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **deleteUnitByID**
> deleteUnitByID(authorization, xAPIKey, id)

Delete Unit By ID

Delete Unit By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 

try { 
    api_instance.deleteUnitByID(authorization, xAPIKey, id);
} catch (e) {
    print("Exception when calling UnitApi->deleteUnitByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 

### Return type

void (empty response body)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **findUnit**
> List<Unit> findUnit(authorization, xAPIKey, limit, offset, sort, direction, filter)

Get Unit List

Get Unit  List

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var limit = 8.14; // num | Limit number result of items Use 0 if you want to get all 
var offset = 8.14; // num | 
var sort = sort_example; // String | 
var direction = direction_example; // String | 
var filter = []; // List<String> | pipe separated field_name|operator|value  example:    - 'id|=|1'   - 'created_at|>=|2017-05-15T17:49:16+07:00'  valid fields:   - \"id\"   - \"name\"  valid operator:   - '='   - '<'   - '<='   - '>'    - '>='   - '!='   - 'contains' (string type only)   - 'not contains' (string type only)   - 'begins' (string type only)   - 'ends' (string type only)   - 'in'   - 'not_in' 

try { 
    var result = api_instance.findUnit(authorization, xAPIKey, limit, offset, sort, direction, filter);
    print(result);
} catch (e) {
    print("Exception when calling UnitApi->findUnit: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **limit** | **num**| Limit number result of items Use 0 if you want to get all  | [optional] [default to 10]
 **offset** | **num**|  | [optional] [default to 0]
 **sort** | **String**|  | [optional] 
 **direction** | **String**|  | [optional] 
 **filter** | [**List&lt;String&gt;**](String.md)| pipe separated field_name|operator|value  example:    - &#39;id|&#x3D;|1&#39;   - &#39;created_at|&gt;&#x3D;|2017-05-15T17:49:16+07:00&#39;  valid fields:   - \&quot;id\&quot;   - \&quot;name\&quot;  valid operator:   - &#39;&#x3D;&#39;   - &#39;&lt;&#39;   - &#39;&lt;&#x3D;&#39;   - &#39;&gt;&#39;    - &#39;&gt;&#x3D;&#39;   - &#39;!&#x3D;&#39;   - &#39;contains&#39; (string type only)   - &#39;not contains&#39; (string type only)   - &#39;begins&#39; (string type only)   - &#39;ends&#39; (string type only)   - &#39;in&#39;   - &#39;not_in&#39;  | [optional] 

### Return type

[**List<Unit>**](Unit.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **getUnitByID**
> Unit getUnitByID(authorization, xAPIKey, id)

Get Unit By ID

Get Unit By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 

try { 
    var result = api_instance.getUnitByID(authorization, xAPIKey, id);
    print(result);
} catch (e) {
    print("Exception when calling UnitApi->getUnitByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 

### Return type

[**Unit**](Unit.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **updateUnitByID**
> Unit updateUnitByID(authorization, xAPIKey, id, body)

Update Unit By ID

Update [object Object] By ID

### Example 
```dart
import 'package:pointpos_api/api.dart';
// TODO Configure API key authorization: JWT
//swagger.api.Configuration.apiKey{'Authorization'} = 'YOUR_API_KEY';
// uncomment below to setup prefix (e.g. Bearer) for API key, if needed
//swagger.api.Configuration.apiKeyPrefix{'Authorization'} = "Bearer";

var api_instance = new UnitApi();
var authorization = authorization_example; // String | JWT Authorization
var xAPIKey = "rtXekst6HDNxgqTG3fc2QWz5N8v4JsZG"; // String | API Key
var id = 8.14; // num | 
var body = new Unit(); // Unit | 

try { 
    var result = api_instance.updateUnitByID(authorization, xAPIKey, id, body);
    print(result);
} catch (e) {
    print("Exception when calling UnitApi->updateUnitByID: $e\n");
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **authorization** | **String**| JWT Authorization | 
 **xAPIKey** | **String**| API Key | 
 **id** | **num**|  | 
 **body** | [**Unit**](Unit.md)|  | 

### Return type

[**Unit**](Unit.md)

### Authorization

[JWT](../README.md#JWT)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)
